.. aioproperty documentation master file, created by
   sphinx-quickstart on Mon Oct 14 21:23:21 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to aioproperty's documentation!
=======================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:

.. mdinclude:: ../../README.md

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
